# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/04_errs.ipynb.

# %% auto 0
__all__ = ['DuckException', 'DuckNameError', 'DuckImportError', 'DuckAttributeError', 'DuckModuleNotFoundError']

# %% ../nbs/04_errs.ipynb 6
#| export


# %% ../nbs/04_errs.ipynb 8
#| export


# %% ../nbs/04_errs.ipynb 10
#| export

# %% ../nbs/04_errs.ipynb 12
#| export

# %% ../nbs/04_errs.ipynb 14
#| export

# %% ../nbs/04_errs.ipynb 16
class DuckException(Exception): ...
    
class DuckNameError(NameError, DuckException): ...
    
class DuckImportError(ImportError, DuckException): ...
    
class DuckAttributeError(AttributeError, DuckException): ...
    
class DuckModuleNotFoundError(ModuleNotFoundError, DuckException): ...
